Struct amazon_sp_easy_ship::models::create_scheduled_packages_response::CreateScheduledPackagesResponse
source · [−]pub struct CreateScheduledPackagesResponse {
pub scheduled_packages: Option<Vec<Package>>,
pub rejected_orders: Option<Vec<RejectedOrder>>,
pub printable_documents_url: Option<String>,
}Expand description
CreateScheduledPackagesResponse : The response schema for the bulk scheduling API. It returns by the bulk scheduling API containing an array of the scheduled packtages, an optional list of orders we couldn’t schedule with the reason, and a pre-signed URL for a ZIP file containing the associated shipping labels plus the documents enabled for your marketplace.
Fields
scheduled_packages: Option<Vec<Package>>A list of packages. Refer to the Package object.
rejected_orders: Option<Vec<RejectedOrder>>A list of orders we couldn’t scheduled on your behalf. Each element contains the reason and details on the error.
printable_documents_url: Option<String>A pre-signed URL for the zip document containing the shipping labels and the documents enabled for your marketplace.
Implementations
sourceimpl CreateScheduledPackagesResponse
impl CreateScheduledPackagesResponse
sourcepub fn new() -> CreateScheduledPackagesResponse
pub fn new() -> CreateScheduledPackagesResponse
The response schema for the bulk scheduling API. It returns by the bulk scheduling API containing an array of the scheduled packtages, an optional list of orders we couldn’t schedule with the reason, and a pre-signed URL for a ZIP file containing the associated shipping labels plus the documents enabled for your marketplace.